==> carbon-component-mapper-3.11.4.tgz: package/esm/prepare-props/prepare-props.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import WithDescription from '../with-description';
import IsRequired from '../is-required/is-required';
export var buildLabel = function buildLabel(label, isRequired) {
  return label && (isRequired ? /*#__PURE__*/React.createElement(IsRequired, null, label) : label) || undefined;
};

var prepareProps = function prepareProps(_ref) {
  var isDisabled = _ref.isDisabled,
      isReadOnly = _ref.isReadOnly,
      _ref$isRequired = _ref.isRequired,
      isRequired = _ref$isRequired === void 0 ? false : _ref$isRequired,
      label = _ref.label,
      description = _ref.description,
      props = _objectWithoutProperties(_ref, ["isDisabled", "isReadOnly", "isRequired", "label", "description"]);

  return _objectSpread(_objectSpread({
    disabled: isDisabled,
    labelText: buildLabel(label, isRequired),
    readOnly: isReadOnly
  }, props), description ? {
    labelText: /*#__PURE__*/React.createElement(WithDescription, {
      description: description,
      labelText: buildLabel(label || props.labelText, isRequired)
    })
  } : {});
};

export default prepareProps;

==> carbon-component-mapper-3.13.0.tgz: package/esm/prepare-props/prepare-props.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["isDisabled", "isReadOnly", "isRequired", "label", "description"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import WithDescription from '../with-description';
import IsRequired from '../is-required/is-required';
export var buildLabel = function buildLabel(label, isRequired) {
  return label && (isRequired ? /*#__PURE__*/React.createElement(IsRequired, null, label) : label) || undefined;
};

var prepareProps = function prepareProps(_ref) {
  var isDisabled = _ref.isDisabled,
      isReadOnly = _ref.isReadOnly,
      _ref$isRequired = _ref.isRequired,
      isRequired = _ref$isRequired === void 0 ? false : _ref$isRequired,
      label = _ref.label,
      description = _ref.description,
      props = _objectWithoutProperties(_ref, _excluded);

  return _objectSpread(_objectSpread({
    disabled: isDisabled,
    labelText: buildLabel(label, isRequired),
    readOnly: isReadOnly
  }, props), description ? {
    labelText: /*#__PURE__*/React.createElement(WithDescription, {
      description: description,
      labelText: buildLabel(label || props.labelText, isRequired)
    })
  } : {});
};

export default prepareProps;
